@@ -3,7 +3,7 @@ from . expr import Parser
 from . mqtt import topic
 
 
-__all__ = ('StateAwareMixin', 'toggle', 'when')
+__all__ = ('StateAwareMixin', 'conditional', 'when')
 
 
 class StateAwareMixin:
@@ -61,34 +61,23 @@ class StateAwareMixin:
                 method(self)
 
 
-def when(expression):
-    ''' Decorator for status handler methods.
-        The decorated method is invoked when the expression depends 
-        on the updated topic and when it evaluates to `True`.
-        For the expression grammar, see the docstrings in `expr.py`.
-    '''
-    
-    predicate = StateAwareMixin.parser.parse(expression)
-    
-    def wrapper(method):
-        id = method.func.__name__ if type(method) is partial else method.__name__
-        
-        @wraps(method)
-        def wrapped(self):
-            if predicate(self.current_state):
-                self.log.debug('Invoking: %s', id)
-                method(self)
-            else:
-                self.log.debug('Skipping: %s', id)
-        StateAwareMixin.conditions[predicate] = wrapped
-        return method
-    return wrapper
+    def publish(self, topic, new_state, **kw):
+        'Avoid redundant updates'
+        old_state = self.current_state.get(topic)
+        if old_state is not None:
+            if old_state == new_state: return
+
+            cast = type(old_state)
+            try:
+                if cast(new_state) == old_state: return
+            except: pass
+        return super().publish(topic, new_state, **kw)
 
 
-def toggle(expression):
-    ''' Decorator for status handler methods.
-        The decorated method is invoked with the value of the expression
-        when the expression depends on the updated topic.
+def conditional(expression):
+    ''' The decorated status handler method is invoked
+        with the value of the expression
+        whenever the expression depends on an updated topic.
         For the expression grammar, see the docstrings in `expr.py`.
     '''
     
@@ -100,8 +89,32 @@ def toggle(expression):
         @wraps(method)
         def wrapped(self):
             condition = predicate(self.current_state)
-            self.log.debug('Invoking: %s(%s)', id, condition)
+            self.log.info('Invoking: %s(%s)', id, condition)
             method(self, condition)
         StateAwareMixin.conditions[predicate] = wrapped
         return method
     return wrapper
+
+
+def when(expression):
+    ''' The decorated status handler method is invoked
+        when the expression depends on an updated topic
+        and when it evaluates to `True`.
+        For the expression grammar, see the docstrings in `expr.py`.
+    '''
+    
+    predicate = StateAwareMixin.parser.parse(expression)
+    
+    def wrapper(method):
+        id = method.func.__name__ if type(method) is partial else method.__name__
+        
+        @wraps(method)
+        def wrapped(self):
+            if predicate(self.current_state):
+                self.log.info('Invoking: %s', id)
+                method(self)
+            else:
+                self.log.debug('Skipping: %s', id)
+        StateAwareMixin.conditions[predicate] = wrapped
+        return method
+    return wrapper
